@@ -21,7 +21,7 @@
 #define _KDIFF3SHELL_H_
 
 #ifdef HAVE_CONFIG_H
-#include <config.h>
+#include "config.h"
 #endif
 
 #include <tdeapplication.h>
